[tor-commits] [tor/master] Deal with the aftermath of sorting contrib

nickm at torproject.org nickm at torproject.org
Mon Apr 28 16:03:06 UTC 2014


commit 703ad69587b512088f178da52494d7767f521c38
Author: Nick Mathewson <nickm at torproject.org>
Date:   Mon Apr 28 11:59:55 2014 -0400

    Deal with the aftermath of sorting contrib
    
    This basically amounts to grepping for every file that mentioned
    contrib and adjusting its references to refer to the right place.
---
 .gitignore                               |   19 +++++--------------
 Makefile.am                              |    6 +++---
 changes/ticket8966                       |    7 +++++++
 configure.ac                             |   12 ++++++------
 contrib/dist/suse/include.am             |    1 -
 contrib/include.am                       |   28 +++++++++++++---------------
 contrib/win32build/package_nsis-mingw.sh |    6 +++---
 doc/HACKING                              |    4 ++--
 doc/tor.1.txt                            |    2 +-
 scripts/maint/redox.py                   |    4 ++--
 scripts/maint/updateVersions.pl          |    2 +-
 11 files changed, 43 insertions(+), 48 deletions(-)

diff --git a/.gitignore b/.gitignore
index 35a6c00..71737cf 100644
--- a/.gitignore
+++ b/.gitignore
@@ -26,6 +26,7 @@
 *.bak
 # Python droppings
 *.pyc
+*.pyo
 
 # /
 /Makefile
@@ -60,20 +61,10 @@
 /tor-*-win32.exe
 
 # /contrib/
-/contrib/Makefile
-/contrib/Makefile.in
-/contrib/tor.sh
-/contrib/torctl
-/contrib/torify
-/contrib/*.pyc
-/contrib/*.pyo
-/contrib/tor.logrotate
-/contrib/tor.wxs
-
-# /contrib/suse/
-/contrib/suse/tor.sh
-/contrib/suse/Makefile.in
-/contrib/suse/Makefile
+/contrib/dist/tor.sh
+/contrib/dist/torctl
+/contrib/operator-tools/tor.logrotate
+/contrib/dist/suse/tor.sh
 
 # /debian/
 /debian/files
diff --git a/Makefile.am b/Makefile.am
index 0361d87..6eceb76 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -77,7 +77,7 @@ reset-gcov:
 # Avoid strlcpy.c, strlcat.c, aes.c, OpenBSD_malloc_Linux.c, sha256.c,
 # eventdns.[hc], tinytest*.[ch]
 check-spaces:
-	./contrib/checkSpace.pl -C                    \
+	./scripts/maint/checkSpace.pl -C              \
 		src/common/*.[ch]		      \
 		src/or/*.[ch]			      \
 		src/test/*.[ch]			      \
@@ -85,10 +85,10 @@ check-spaces:
 		src/tools/tor-fw-helper/*.[ch]
 
 check-docs:
-	./contrib/checkOptionDocs.pl
+	./scripts/maint/checkOptionDocs.pl
 
 check-logs:
-	./contrib/checkLogs.pl                        \
+	./scripts/maint/checkLogs.pl                  \
 		src/*/*.[ch] | sort -n
 
 version:
diff --git a/changes/ticket8966 b/changes/ticket8966
new file mode 100644
index 0000000..d6967a4
--- /dev/null
+++ b/changes/ticket8966
@@ -0,0 +1,7 @@
+  o Package cleanup:
+    - The contrib directory has been sorted and tidy. Before, it was an
+      unsorted dumping ground for useful and not-so-useful things. Now,
+      it has been divided based on functionality, and the items which
+      seemed to be nonfunctional or useless have been removed. Resolves
+      ticket 8966; based on patches from "rl1987".
+
diff --git a/configure.ac b/configure.ac
index edfe2f8..f921dd5 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1557,10 +1557,10 @@ CPPFLAGS="$CPPFLAGS $TOR_CPPFLAGS_libevent $TOR_CPPFLAGS_openssl $TOR_CPPFLAGS_z
 AC_CONFIG_FILES([
         Doxyfile
         Makefile
-        contrib/suse/tor.sh
-        contrib/tor.logrotate
-        contrib/tor.sh
-        contrib/torctl
+        contrib/dist/suse/tor.sh
+        contrib/operator-tools/tor.logrotate
+        contrib/dist/tor.sh
+        contrib/dist/torctl
         src/config/torrc.sample
 ])
 
@@ -1582,6 +1582,6 @@ fi
 
 AC_OUTPUT
 
-if test -x /usr/bin/perl && test -x ./contrib/updateVersions.pl ; then
-  ./contrib/updateVersions.pl
+if test -x /usr/bin/perl && test -x ./scripts/maint/updateVersions.pl ; then
+  ./scripts/maint/updateVersions.pl
 fi
diff --git a/contrib/dist/suse/include.am b/contrib/dist/suse/include.am
deleted file mode 100644
index 4aed0e1..0000000
--- a/contrib/dist/suse/include.am
+++ /dev/null
@@ -1 +0,0 @@
-EXTRA_DIST+= contrib/suse/tor.sh
diff --git a/contrib/include.am b/contrib/include.am
index 62b76eb..0120798 100644
--- a/contrib/include.am
+++ b/contrib/include.am
@@ -1,18 +1,16 @@
-include contrib/suse/include.am
 
 EXTRA_DIST+= \
-	contrib/cross.sh			\
-	contrib/exitlist			\
-	contrib/linux-tor-prio.sh		\
-	contrib/package_nsis-mingw.sh		\
-	contrib/rc.subr				\
-	contrib/tor-ctrl.sh			\
-	contrib/tor-exit-notice.html		\
-	contrib/tor-mingw.nsi.in		\
-	contrib/tor.ico				\
-	contrib/tor.nsi.in			\
-	contrib/tor.sh				\
-	contrib/torify				\
-	contrib/torctl
+	contrib/client-tools/torify			\
+	contrib/dist/rc.subr				\
+	contrib/dist/suse/tor.sh.in			\
+	contrib/dist/tor.sh				\
+	contrib/dist/torctl				\
+	contrib/operator-tools/linux-tor-prio.sh	\
+	contrib/operator-tools/tor-exit-notice.html	\
+	contrib/or-tools/exitlist			\
+	contrib/win32build/package_nsis-mingw.sh	\
+	contrib/win32build/tor-mingw.nsi.in		\
+	contrib/win32build/tor.ico			\
+	contrib/win32build/tor.nsi.in
 
-bin_SCRIPTS+= contrib/torify
+bin_SCRIPTS+= contrib/client-tools/torify
diff --git a/doc/HACKING b/doc/HACKING
index 28d4c5e..2156f7c 100644
--- a/doc/HACKING
+++ b/doc/HACKING
@@ -122,7 +122,7 @@ Running gcov for unit test coverage
    make
    make check
    mkdir coverage-output
-   ./contrib/coverage coverage-output
+   ./scripts/test/coverage coverage-output
 -----
 
 (On OSX, you'll need to start with "--enable-coverage CC=clang".)
@@ -142,7 +142,7 @@ If you have two different "coverage-output" directories, and you want to see
 a meaningful diff between them, you can run:
 
 -----
-   ./contrib/cov-diff coverage-output1 coverage-output2 | less
+   ./scripts/test/cov-diff coverage-output1 coverage-output2 | less
 -----
 
 In this diff, any lines that were visited at least once will have coverage
diff --git a/doc/tor.1.txt b/doc/tor.1.txt
index 94c7d40..79368f5 100644
--- a/doc/tor.1.txt
+++ b/doc/tor.1.txt
@@ -1782,7 +1782,7 @@ if DirPort is non-zero):
     When this option is set, it takes an HTML file and publishes it as "/" on
     the DirPort. Now relay operators can provide a disclaimer without needing
     to set up a separate webserver. There's a sample disclaimer in
-    contrib/tor-exit-notice.html.
+    contrib/operator-tools/tor-exit-notice.html.
 
 [[V3AuthoritativeDirectory]] **V3AuthoritativeDirectory** **0**|**1**::
     When this option is set in addition to **AuthoritativeDirectory**, Tor
diff --git a/scripts/maint/redox.py b/scripts/maint/redox.py
index 550f846..fa816a7 100755
--- a/scripts/maint/redox.py
+++ b/scripts/maint/redox.py
@@ -10,7 +10,7 @@
 #   to tell you where documentation should go!
 # To use me, edit the stuff below...
 #  ...and run 'make doxygen 2>doxygen.stderr' ...
-#  ...and run ./contrib/redox.py < doxygen.stderr !
+#  ...and run ./scripts/maint/redox.py < doxygen.stderr !
 # I'll make a bunch of new files by adding missing DOCDOC comments to your
 #    source.  Those files will have names like ./src/common/util.c.newdoc.
 # You will want to look over the changes by hand before checking them in.
@@ -21,7 +21,7 @@
 # 1. make doxygen 1>doxygen.stdout 2>doxygen.stderr.
 # 2. grep Warning doxygen.stderr | grep -v 'is not documented' | less
 #      [This will tell you about all the bogus doxygen output you have]
-# 3. python ./contrib/redox.py <doxygen.stderr
+# 3. python ./scripts/maint/redox.py <doxygen.stderr
 #      [This will make lots of .newdoc files with DOCDOC comments for
 #       whatever was missing documentation.]
 # 4. Look over those .newdoc files, and see which docdoc comments you
diff --git a/scripts/maint/updateVersions.pl b/scripts/maint/updateVersions.pl
index 9dae1ff..15c83b8 100755
--- a/scripts/maint/updateVersions.pl
+++ b/scripts/maint/updateVersions.pl
@@ -2,7 +2,7 @@
 
 $CONFIGURE_IN = './configure.ac';
 $ORCONFIG_H = './src/win32/orconfig.h';
-$TOR_NSI = './contrib/tor-mingw.nsi.in';
+$TOR_NSI = './contrib/win32build/tor-mingw.nsi.in';
 
 $quiet = 1;
 





More information about the tor-commits mailing list
diff --git a/contrib/win32build/package_nsis-mingw.sh b/contrib/win32build/package_nsis-mingw.sh
index b8a46cd..cae862b 100644
--- a/contrib/win32build/package_nsis-mingw.sh
+++ b/contrib/win32build/package_nsis-mingw.sh
@@ -40,7 +40,7 @@
 # you know what you are doing.
 
 # Start in the tor source directory after you've compiled tor.exe
 # This means start as ./contrib/package_nsis-mingw.sh
 
 rm -rf win_tmp
 mkdir win_tmp
@@ -56,7 +56,7 @@ mkdir win_tmp/tmp
 
 cp src/or/tor.exe win_tmp/bin/
 cp src/tools/tor-resolve.exe win_tmp/bin/
-cp contrib/tor.ico win_tmp/bin/
+cp contrib/win32build/tor.ico win_tmp/bin/
 cp src/config/geoip win_tmp/bin/
 strip win_tmp/bin/*.exe
 
@@ -88,7 +88,7 @@ done
 
 clean_localstatedir src/config/torrc.sample.in win_tmp/src/config/torrc.sample
 
-cp contrib/tor-mingw.nsi.in win_tmp/contrib/
+cp contrib/win32build/tor-mingw.nsi.in win_tmp/contrib/
 
 cd win_tmp
 makensis.exe contrib/tor-mingw.nsi.in
@@ -40,7 +40,7 @@
 
 # Start in the tor source directory after you've compiled tor.exe
-# This means start as ./contrib/package_nsis-mingw.sh
+# This means start as ./contrib/win32build/package_nsis-mingw.sh
 
 rm -rf win_tmp